@@ -7,8 +7,8 @@ test_that("all records is a large number", {
   num <- idig_count_records()
 
   expect_that(num, is_a("integer"))
-  expect_that((num - num) == 0, is_true())
-  expect_that(num > 20 * 1000 * 1000, is_true())
+  expect_true((num - num) == 0)
+  expect_true(num > 20 * 1000 * 1000)
 })
 
 test_that("rq searches on the endpoint is a small number", {
@@ -16,5 +16,5 @@ test_that("rq searches on the endpoint is a small number", {
   num <- idig_count_records(rq=list("recordset"=recordset))
   
   expect_that(num, is_a("integer"))
-  expect_that(num > 400 * 1000, is_true())
+  expect_true(num > 400 * 1000)
 })
\ No newline at end of file
