@@ -7,24 +7,24 @@ test_that("records field list returns", {
   expect_that(f, is_a("list"))
   expect_that(f[["data"]], is_a("list"))
   expect_that(f[["indexData"]], is_a("list"))
-  expect_that(f[["uuid"]][["type"]] == "string", is_true())
+  expect_true(f[["uuid"]][["type"]] == "string")
 })
 
 test_that("records indexed subset returns", {
   testthat::skip_on_cran()
   f <- idig_meta_fields(subset="indexed")
   
-  expect_that(f[["data"]], is_null())
-  expect_that(f[["indexData"]], is_null())
-  expect_that(f[["uuid"]][["type"]] == "string", is_true())
+  expect_null(f[["data"]])
+  expect_null(f[["indexData"]])
+  expect_true(f[["uuid"]][["type"]] == "string")
 })
 
 test_that("records raw subset returns", {
   testthat::skip_on_cran()
   f <- idig_meta_fields(subset="raw")
   
-  expect_that(f[["uuid"]], is_null())
-  expect_that(f[["dwc:occurrenceID"]][["type"]] == "string", is_true())
+  expect_null(f[["uuid"]])
+  expect_true(f[["dwc:occurrenceID"]][["type"]] == "string")
 })
 
 test_that("media list returns", {
@@ -34,22 +34,22 @@ test_that("media list returns", {
   expect_that(f, is_a("list"))
   expect_that(f[["data"]], is_a("list"))
   expect_that(f[["indexData"]], is_a("list"))
-  expect_that(f[["uuid"]][["type"]] == "string", is_true())
+  expect_true(f[["uuid"]][["type"]] == "string")
 })
 
 test_that("media indexed subset returns", {
   testthat::skip_on_cran()
   f <- idig_meta_fields(type="media", subset="indexed")
   
-  expect_that(f[["data"]], is_null())
-  expect_that(f[["indexData"]], is_null())
-  expect_that(f[["uuid"]][["type"]] == "string", is_true())
+  expect_null(f[["data"]])
+  expect_null(f[["indexData"]])
+  expect_true(f[["uuid"]][["type"]] == "string")
 })
 
 test_that("media raw subset returns", {
   testthat::skip_on_cran()
   f <- idig_meta_fields(type="media", subset="raw")
   
-  expect_that(f[["uuid"]], is_null())
-  expect_that(f[["ac:accessURI"]][["type"]] == "string", is_true())
+  expect_null(f[["uuid"]])
+  expect_true(f[["ac:accessURI"]][["type"]] == "string")
 })
\ No newline at end of file
