@@ -9,9 +9,9 @@ test_that("viewing a media record returns right information", {
   expect_that(med, is_a("list"))
   expect_that(med$uuid, equals(med_uuid))
   expect_that(med$data, is_a("list"))
-  expect_that(length(med$data$coreid) > 0, is_true())
+  expect_true(length(med$data$coreid) > 0)
   expect_that(med$indexTerms, is_a("list"))
   expect_that(med$indexTerms$uuid, equals(med_uuid))
   expect_that(med$attribution, is_a("list"))
-  expect_that(length(med$attribution$description) > 0, is_true())
+  expect_true(length(med$attribution$description) > 0)
 })
\ No newline at end of file
