@@ -9,9 +9,9 @@ test_that("viewing a record returns right information", {
   expect_that(rec, is_a("list"))
   expect_that(rec$uuid, equals(rec_uuid))
   expect_that(rec$data, is_a("list"))
-  expect_that(length(rec$data$id) > 0, is_true())
+  expect_true(length(rec$data$id) > 0)
   expect_that(rec$indexTerms, is_a("list"))
   expect_that(rec$indexTerms$uuid, equals(rec_uuid))
   expect_that(rec$attribution, is_a("list"))
-  expect_that(length(rec$attribution$data_rights) > 0, is_true())
+  expect_true(length(rec$attribution$data_rights) > 0)
 })
